@@ -1,5 +1,5 @@
 /*
- * Copyright 2011-2021 Arx Libertatis Team (see the AUTHORS file)
+ * Copyright 2011-2022 Arx Libertatis Team (see the AUTHORS file)
  *
  * This file is part of Arx Libertatis.
  *
@@ -123,7 +123,7 @@ static void PopOneTriangleList(RenderState baseState, TextureContainer * materia
 		GRenderer->GetTextureStage(0)->setMipMapLODBias(GLOBAL_NPC_MIPMAP_BIAS);
 	}
 	
-	EERIEDRAWPRIM(Renderer::TriangleList, &bucket[0], bucket.size());
+	EERIEDRAWPRIM(Renderer::TriangleList, bucket.data(), bucket.size());
 	
 	if(clear) {
 		bucket.clear();
