@@ -1,5 +1,5 @@
 /*
- * Copyright 2011-2021 Arx Libertatis Team (see the AUTHORS file)
+ * Copyright 2011-2022 Arx Libertatis Team (see the AUTHORS file)
  *
  * This file is part of Arx Libertatis.
  *
@@ -525,14 +525,14 @@ static void LoadSysTextures() {
 
 	spellDataInit();
 
-	enviro = TextureContainer::LoadUI("graph/particles/enviro");
+	enviro = TextureContainer::LoadUI("graph/particles/enviro", TextureContainer::NoColorKey);
 	
 	ARX_INTERFACE_DrawNumberInit();
 	initLightFlares();
 	ombrignon = TextureContainer::LoadUI("graph/particles/ombrignon");
-	TC_fire = TextureContainer::LoadUI("graph/particles/fire");
-	TC_fire2 = TextureContainer::LoadUI("graph/particles/fire2");
-	TC_smoke = TextureContainer::LoadUI("graph/particles/smoke");
+	TC_fire = TextureContainer::LoadUI("graph/particles/fire", TextureContainer::NoColorKey);
+	TC_fire2 = TextureContainer::LoadUI("graph/particles/fire2", TextureContainer::NoColorKey);
+	TC_smoke = TextureContainer::LoadUI("graph/particles/smoke", TextureContainer::NoColorKey);
 	Boom = TextureContainer::LoadUI("graph/particles/boom");
 	arx_logo_tc = TextureContainer::LoadUI("graph/interface/icons/arx_logo_32");
 	
