@@ -1,5 +1,5 @@
 /*
- * Copyright 2011-2021 Arx Libertatis Team (see the AUTHORS file)
+ * Copyright 2011-2022 Arx Libertatis Team (see the AUTHORS file)
  *
  * This file is part of Arx Libertatis.
  *
@@ -128,6 +128,7 @@ ZeniMax Media Inc., Suite 120, Rockville, Maryland 20850 USA.
 #include "scene/GameSound.h"
 #include "scene/Interactive.h"
 #include "scene/Light.h"
+#include "scene/LoadLevel.h"
 #include "scene/Object.h"
 
 #include "script/Script.h"
@@ -398,9 +399,9 @@ static PlayerMisc getMiscStats(const PlayerAttribute & attribute, const PlayerSk
 	
 	PlayerMisc stats;
 	
-	stats.armorClass   = std::max(1.f, skill.defense * 0.1f - 1.0f);
-	stats.resistMagic  = attribute.mind * 2.f * (1.f + skill.casting * 0.005f); // TODO why *?
-	stats.resistPoison = attribute.constitution * 2.f + skill.defense * 0.25f;
+	stats.armorClass   = std::floor(std::max(1.f, skill.defense * 0.1f - 1.0f));
+	stats.resistMagic  = std::floor(attribute.mind * 2.f * (1.f + skill.casting * 0.005f)); // TODO why *?
+	stats.resistPoison = std::floor(attribute.constitution * 2.f + skill.defense * 0.25f);
 	stats.criticalHit  = attribute.dexterity * 2.f + skill.closeCombat * 0.2f - 18.f;
 	stats.damages      = std::max(1.f, attribute.strength * 0.5f - 5.f);
 	
@@ -674,9 +675,9 @@ void ARX_PLAYER_ComputePlayerFullStats() {
 	);
 	
 	// Calculate full stats
-	player.m_miscFull.armorClass = std::floor(std::max(0.f, miscBase.armorClass + player.m_miscMod.armorClass));
-	player.m_miscFull.resistMagic = std::floor(std::max(0.f, miscBase.resistMagic + player.m_miscMod.resistMagic));
-	player.m_miscFull.resistPoison = std::floor(std::max(0.f, miscBase.resistPoison + player.m_miscMod.resistPoison));
+	player.m_miscFull.armorClass = std::max(0.f, miscBase.armorClass + player.m_miscMod.armorClass);
+	player.m_miscFull.resistMagic = std::max(0.f, miscBase.resistMagic + player.m_miscMod.resistMagic);
+	player.m_miscFull.resistPoison = std::max(0.f, miscBase.resistPoison + player.m_miscMod.resistPoison);
 	player.m_miscFull.criticalHit = std::max(0.f, miscBase.criticalHit + player.m_miscMod.criticalHit);
 	player.m_miscFull.damages = std::max(1.f, miscBase.damages + player.m_miscMod.damages
 	                                          + player.m_skillFull.closeCombat * 0.1f);
@@ -2381,14 +2382,12 @@ void ARX_PLAYER_Start_New_Quest() {
 	
 	LogInfo << "Starting a new playthrough";
 	
+	DanaeClearLevel();
+	SetEditMode();
+	
 	g_characterCreation.resetCheat();
-	EERIE_PATHFINDER_Clear();
-	EERIE_PATHFINDER_Release();
-	ARX_PLAYER_MakeFreshHero();
 	player.torch = NULL;
-	entities.clear();
 	svar.clear();
-	ARX_EQUIPMENT_UnEquipAllPlayer();
 	
 	ARX_CHANGELEVEL_StartNew();
 	
