@@ -606,13 +606,13 @@ void ARX_SPELLS_ManageMagic() {
 		CheatDetectionReset();
 		
 		if(CurrSpellSymbol != 0) {
-			if(!ARX_SPELLS_AnalyseSPELL()) {
+			if(ARX_SPELLS_AnalyseSPELL()) {
 				if(io->anims[ANIM_CAST]) {
 					changeAnimation(io, 1, io->anims[ANIM_CAST]);
 				}
 			}
 		}
-
+		
 		ARX_FLARES_broken = 1;
 
 		if(WILLRETURNTOCOMBATMODE) {
