@@ -1,5 +1,5 @@
 /*
- * Copyright 2011-2021 Arx Libertatis Team (see the AUTHORS file)
+ * Copyright 2011-2022 Arx Libertatis Team (see the AUTHORS file)
  *
  * This file is part of Arx Libertatis.
  *
@@ -328,7 +328,7 @@ void OpenGLRenderer::initialize() {
 
 void OpenGLRenderer::beforeResize(bool wasOrIsFullscreen) {
 	
-#if ARX_PLATFORM == ARX_PLATFORM_LINUX || ARX_PLATFORM == ARX_PLATFORM_BSD
+#if ARX_PLATFORM == ARX_PLATFORM_LINUX || ARX_PLATFORM == ARX_PLATFORM_BSD || ARX_PLATFORM == ARX_PLATFORM_HAIKU
 	// No re-initialization needed
 	ARX_UNUSED(wasOrIsFullscreen);
 #else
