@@ -1,5 +1,5 @@
 /*
- * Copyright 2011-2021 Arx Libertatis Team (see the AUTHORS file)
+ * Copyright 2011-2022 Arx Libertatis Team (see the AUTHORS file)
  *
  * This file is part of Arx Libertatis.
  *
@@ -1800,7 +1800,7 @@ void ArxGame::manageEditorControls() {
 				} else if(io != COMBINE) {
 					combineEntities(COMBINE, io);
 				}
-			} else { // GLights
+			} else if(COMBINE) { // GLights
 				float fMaxdist = player.m_telekinesis ? 850 : 300;
 				
 				for(size_t i = 0; i < g_staticLightsMax; i++) {
@@ -1903,7 +1903,7 @@ void ArxGame::manageEditorControls() {
 				if(io && (!g_cursorOverBook || io->show == SHOW_FLAG_ON_PLAYER)) {
 					
 					if(io->show == SHOW_FLAG_ON_PLAYER) {
-						ARX_EQUIPMENT_UnEquip(entities.player(), io);
+						ARX_EQUIPMENT_UnEquip(entities.player(), io, 1);
 						io->bbox2D.max.x = -1;
 					}
 					
