@@ -1,5 +1,5 @@
 /*
- * Copyright 2013-2020 Arx Libertatis Team (see the AUTHORS file)
+ * Copyright 2013-2022 Arx Libertatis Team (see the AUTHORS file)
  *
  * This file is part of Arx Libertatis.
  *
@@ -211,6 +211,8 @@ std::string getOSName() {
 	return "macOS";
 	#elif ARX_PLATFORM == ARX_PLATFORM_BSD
 	return "BSD";
+	#elif ARX_PLATFORM == ARX_PLATFORM_HAIKU
+	return "Haiku";
 	#elif ARX_PLATFORM == ARX_PLATFORM_UNIX
 	return "UNIX";
 	#else
