@@ -1,5 +1,5 @@
 /*
- * Copyright 2011-2021 Arx Libertatis Team (see the AUTHORS file)
+ * Copyright 2011-2022 Arx Libertatis Team (see the AUTHORS file)
  *
  * This file is part of Arx Libertatis.
  *
@@ -200,8 +200,6 @@ void ARX_INTERACTIVE_DestroyDynamicInfo(Entity * io)
 		}
 	}
 	
-	ARX_SPEECH_ReleaseIOSpeech(io);
-	
 	ARX_SCRIPT_EventStackClearForIo(io);
 	
 	if(ValidIONum(n)) {
@@ -2315,7 +2313,7 @@ void ARX_INTERACTIVE_ActivatePhysics(EntityHandle t) {
 	Entity * io = entities.get(t);
 	if(io) {
 		
-		if(io == g_draggedEntity || io->show != SHOW_FLAG_IN_SCENE) {
+		if(io == g_draggedEntity || io->show != SHOW_FLAG_IN_SCENE || !io->obj || !io->obj->pbox) {
 			return;
 		}
 		
